@@ -1,12 +1,15 @@
 /*
  * AJD4JP
- * Copyright (c) 2011  Akira Terasaki
+ * Copyright (c) 2011-2021  Akira Terasaki
  * このファイルは同梱されているLicense.txtに定めた条件に
  * 同意できる場合にのみ利用可能です。
  */
 package ajd4jp;
 
-import java.math.*;
+import java.math.BigDecimal;
+import java.time.ZoneId;
+
+import ajd4jp.iso.Year;
 
 
 /**
@@ -19,18 +22,30 @@ public interface Day extends Comparable<Day>, java.io.Serializable {
 	 */
 	public BigDecimal getAJD();
 	/**
-	 * ユリウス通日の取得。
-	 * @return ユリウス通日。
+	 * AJDの取得。
+	 * @return AJD。
 	 */
 	public AJD toAJD();
 
 	/**
-	 * ユリウス通日の比較。
+	 * 比較。
 	 * @param jd 比較対象。
 	 * @return 比較結果。
 	 */
 	public int compareTo( Day jd );
 
+	/**
+	 * タイムゾーン取得。
+	 * @return 常に+9時間を返します。
+	 */
+	default public ZoneId getZoneId() {
+		return AJD.OFFSET;
+	}
+	/**
+	 * 年の取得。
+	 * @return 年。
+	 */
+	default public Year toYear() { return Year.fromAJD(getYear(), getZoneId()); }
 	/**
 	 * 年の取得。
 	 * @return 年。0は返りません。
